﻿using System;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using CustomSettingsPane.ViewModels;
using Telerik.Windows.DragDrop;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.Diagrams;
using Telerik.Windows.Diagrams.Core;

namespace CustomSettingsPane
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            SerializationService.Default.ItemSerializing += DefaultSerializationService_ItemSerializing;
            DragDropManager.AddDragInitializeHandler(this.toolbox, OnToolboxDragInitialized, true);
            DragDropManager.AddDropHandler(this.diagram, OnDiagramDrop);
        }

        private void DefaultSerializationService_ItemSerializing(object sender, SerializationEventArgs<IDiagramItem> e)
        {
            if (e.Entity != null && e.Entity is RadDiagramShape)
            {
                var shape = e.Entity as RadDiagramShape;
                if (shape.Geometry != null)
                {
                    e.SerializationInfo["MyGeometry"] = (e.Entity as RadDiagramShape).Geometry.ToString();
                }
            }
        }

        private void OnToolboxDragInitialized(object sender, DragInitializeEventArgs args)
        {
            args.AllowedEffects = DragDropEffects.All;
            args.Handled = true;
            args.Data = ((FrameworkElement)args.OriginalSource).DataContext;
            args.DragVisual = new ContentControl { Content = args.Data, ContentTemplate = this.LayoutRoot.Resources["ToolboxItemTemplate"] as DataTemplate };
        }

        private void OnDiagramDrop(object sender, Telerik.Windows.DragDrop.DragEventArgs e)
        {
            e.Handled = true;
            ShapeViewModel draggedData = (e.Data as DataObject).GetData(typeof(ShapeViewModel)) as ShapeViewModel;
            var currentPosition = diagram.GetTransformedPoint(e.GetPosition(diagram));
            draggedData.Position = new Point(currentPosition.X, currentPosition.Y);

            if (draggedData != null)
                ((sender as RadDiagram).GraphSource as GraphSource).AddNode(draggedData);
        }


    }
}
